# pySparkUtils
[![Build Status](https://travis-ci.org/boazmohar/pySparkUtils.svg?branch=master)](https://travis-ci.org/boazmohar/pySparkUtils)
[![PyPI version](https://badge.fury.io/py/pySparkUtils.svg)](https://badge.fury.io/py/pySparkUtils)
[![Updates](https://pyup.io/repos/github/boazmohar/pySparkUtils/shield.svg)](https://pyup.io/repos/github/boazmohar/pySparkUtils/)

A collection of utilities for handling pySpark's SparkContext

## install

```
pip install pySparkUtil
```

## support

Tested on Spark 2.1 with python 2.7 and 3.5

## documentation

[API Documentation](https://boazmohar.github.io/pySparkUtils/pySparkUtils.html#module-pySparkUtils.utils)

## contributing

Fell free to create issues or PR's
